@@ -1,13 +1,14 @@
 """ Redfish restful library """
 
-__all__ = ['rest', 'ris', 'hpilo']
-__version__ = "3.5.1.0"
+__all__ = ["rest", "ris", "hpilo"]
+__version__ = "3.6.0.0"
 
 import logging
 from redfish.rest.v1 import AuthMethod, LegacyRestClient, RedfishClient
 
+
 def redfish_logger(file_name, log_format, log_level=logging.ERROR):
-    """ redfish logger """
+    """redfish logger"""
     formatter = logging.Formatter(log_format)
     fhdl = logging.FileHandler(file_name)
     fhdl.setFormatter(formatter)
