@@ -50,36 +50,46 @@ LOGGER = logging.getLogger(__name__)
 
 # ---------End of debug logger---------
 
+
 class RetriesExhaustedError(Exception):
     """Raised when retry attempts have been exhausted."""
+
     pass
 
+
 class VnicNotEnabledError(Exception):
     """Raised when retry attempts have been exhausted when VNIC is not enabled."""
+
     pass
 
+
 class DecompressResponseError(Exception):
     """Raised when decompressing the response failed."""
+
     pass
 
 
 class InvalidCredentialsError(Exception):
     """Raised when invalid credentials have been provided."""
+
     pass
 
 
 class InvalidCertificateError(Exception):
     """Raised when a invalid certificate has been provided."""
+
     pass
 
 
 class ChifDriverMissingOrNotFound(Exception):
     """Raised when CHIF driver is missing or not found."""
+
     pass
 
 
 class SecurityStateError(Exception):
     """Raised when there is a strict security state without authentication."""
+
     pass
 
 
@@ -88,20 +98,19 @@ class HttpConnection(object):
 
     :param base_url: The URL to make HTTP calls against
     :type base_url: str
-    :param \\**client_kwargs: Arguments to pass to the connection initialization. These are """ \
-    "passed to a urllib3 `PoolManager <https://urllib3.readthedocs.io/en/latest/reference/" \
-    "index.html?highlight=PoolManager#urllib3.PoolManager>`_. All arguments that can be passed to " \
-    "a PoolManager are valid arguments."
+    :param \\**client_kwargs: Arguments to pass to the connection initialization. These are """ "passed to a urllib3 `PoolManager <https://urllib3.readthedocs.io/en/latest/reference/" "index.html?highlight=PoolManager#urllib3.PoolManager>`_. All arguments that can be passed to " "a PoolManager are valid arguments."
 
     def __init__(self, base_url, cert_data, **client_kwargs):
         self._conn = None
         self.base_url = base_url
         self._connection_properties = client_kwargs
         if cert_data:
-            if ('cert_file' in cert_data and cert_data['cert_file']) or ('ca_certs' in cert_data and cert_data['ca_certs']):
-                self._connection_properties.update({'ca_cert_data': cert_data})
-        self._proxy = self._connection_properties.pop('proxy', None)
-        self.session_key = self._connection_properties.pop('session_key', None)
+            if ("cert_file" in cert_data and cert_data["cert_file"]) or (
+                "ca_certs" in cert_data and cert_data["ca_certs"]
+            ):
+                self._connection_properties.update({"ca_cert_data": cert_data})
+        self._proxy = self._connection_properties.pop("proxy", None)
+        self.session_key = self._connection_properties.pop("session_key", None)
         self._init_connection()
 
     @property
@@ -116,36 +125,53 @@ class HttpConnection(object):
 
     def _init_connection(self):
         """Function for initiating connection with remote server"""
-        cert_reqs = 'CERT_NONE'
-        if self._connection_properties.get('ca_cert_data'):
-            LOGGER.info('Using CA cert to confirm identity.')
-            cert_reqs = 'CERT_NONE'
-            self._connection_properties.update(self._connection_properties.pop('ca_cert_data'))
+        cert_reqs = "CERT_NONE"
+        if self._connection_properties.get("ca_cert_data"):
+            LOGGER.info("Using CA cert to confirm identity.")
+            cert_reqs = "CERT_NONE"
+            self._connection_properties.update(
+                self._connection_properties.pop("ca_cert_data")
+            )
 
         if self.proxy:
-            if self.proxy.startswith('socks'):
+            if self.proxy.startswith("socks"):
                 LOGGER.info("Initializing a SOCKS proxy.")
-                http = SOCKSProxyManager(self.proxy, cert_reqs=cert_reqs, maxsize=6,
-                                         **self._connection_properties)
+                http = SOCKSProxyManager(
+                    self.proxy,
+                    cert_reqs=cert_reqs,
+                    maxsize=6,
+                    **self._connection_properties
+                )
             else:
                 LOGGER.info("Initializing a HTTP proxy.")
-                http = ProxyManager(self.proxy, cert_reqs=cert_reqs, maxsize=6,
-                                    **self._connection_properties)
+                http = ProxyManager(
+                    self.proxy,
+                    cert_reqs=cert_reqs,
+                    maxsize=6,
+                    **self._connection_properties
+                )
         else:
             LOGGER.info("Initializing no proxy.")
             try:
-                self._connection_properties.pop('ca_cert_data')
+                self._connection_properties.pop("ca_cert_data")
             except KeyError:
                 pass
             timeout = urllib3.util.Timeout(connect=40.0, read=None)
             if "timeout" not in self._connection_properties:
-                http = PoolManager(cert_reqs=cert_reqs, maxsize=6, timeout=timeout, **self._connection_properties)
+                http = PoolManager(
+                    cert_reqs=cert_reqs,
+                    maxsize=6,
+                    timeout=timeout,
+                    **self._connection_properties
+                )
             else:
-                http = PoolManager(cert_reqs=cert_reqs, maxsize=6, **self._connection_properties)
+                http = PoolManager(
+                    cert_reqs=cert_reqs, maxsize=6, **self._connection_properties
+                )
 
         self._conn = http.request
 
-    def rest_request(self, path, method='GET', args=None, body=None, headers=None):
+    def rest_request(self, path, method="GET", args=None, body=None, headers=None):
         """Format and do HTTP Rest request
 
         :param path: The URI path to perform the operation on.
@@ -164,34 +190,35 @@ class HttpConnection(object):
         files = None
         request_args = {}
         if isinstance(path, bytes):
-            path = str(path, "utf-8")
-            external_uri = True if 'redfish.dmtf.org' in path else False
+            path = path.decode("utf-8")
+            external_uri = True if "redfish.dmtf.org" in path else False
         else:
-            external_uri = True if 'redfish.dmtf.org' in path else False
+            external_uri = True if "redfish.dmtf.org" in path else False
         headers = {} if external_uri else headers
-        reqpath = path.replace('//', '/') if not external_uri else path
+        reqpath = path.replace("//", "/") if not external_uri else path
 
         if body is not None:
             if body and isinstance(body, list) and isinstance(body[0], tuple):
                 files = body
                 body = None
             elif isinstance(body, (dict, list)):
-                headers['Content-Type'] = 'application/json'
+                headers["Content-Type"] = "application/json"
                 body = json.dumps(body)
             elif not files:
-                headers['Content-Type'] = 'application/octet-stream'
+                headers["Content-Type"] = "application/octet-stream"
 
-            if method == 'PUT':
-                resp = self.rest_request(method='HEAD', path=path, headers=headers)
+            if method == "PUT":
+                resp = self.rest_request(method="HEAD", path=path, headers=headers)
 
                 try:
-                    if resp.getheader('content-encoding') == 'gzip':
+                    if resp.getheader("content-encoding") == "gzip":
                         buf = BytesIO()
-                        gfile = gzip.GzipFile(mode='wb', fileobj=buf)
+                        gfile = gzip.GzipFile(mode="wb", fileobj=buf)
 
                         try:
-                            gfile.write(str(body).encode('utf-8') if six.PY3 \
-                                            else str(body))
+                            gfile.write(
+                                str(body).encode("utf-8") if six.PY3 else str(body)
+                            )
                         finally:
                             gfile.close()
 
@@ -201,44 +228,54 @@ class HttpConnection(object):
                             data.extend(memoryview(compresseddata))
                             body = data
                 except BaseException as excp:
-                    LOGGER.error('Error occur while compressing body: %s', excp)
+                    LOGGER.error("Error occur while compressing body: %s", excp)
                     raise
 
         if args:
-            if method == 'GET':
-                reqpath += '?' + urlencode(args)
-            elif method == 'PUT' or method == 'POST' or method == 'PATCH':
-                headers['Content-Type'] = 'application/x-www-form-urlencoded'
+            if method == "GET":
+                reqpath += "?" + urlencode(args)
+            elif method == "PUT" or method == "POST" or method == "PATCH":
+                headers["Content-Type"] = "application/x-www-form-urlencoded"
                 body = urlencode(args)
 
         # TODO: ADD to the default headers?
         if headers != None:
-            headers['Accept-Encoding'] = 'gzip'
-        restreq = RestRequest(path, method, data=files if files else body, url=self.base_url)
+            headers["Accept-Encoding"] = "gzip"
+        restreq = RestRequest(
+            path, method, data=files if files else body, url=self.base_url
+        )
 
         if LOGGER.isEnabledFor(logging.DEBUG):
             try:
                 logbody = None
                 if restreq.body:
-                    if restreq.body[0] == '{':
+                    if restreq.body[0] == "{":
                         logbody = restreq.body
                     else:
                         raise KeyError()
-                if restreq.method in ['POST', 'PATCH']:
+                if restreq.method in ["POST", "PATCH"]:
                     debugjson = json.loads(restreq.body)
-                    if 'Password' in debugjson.keys():
-                        debugjson['Password'] = '******'
-                    if 'OldPassword' in debugjson.keys():
-                        debugjson['OldPassword'] = '******'
-                    if 'NewPassword' in debugjson.keys():
-                        debugjson['NewPassword'] = '******'
+                    if "Password" in debugjson.keys():
+                        debugjson["Password"] = "******"
+                    if "OldPassword" in debugjson.keys():
+                        debugjson["OldPassword"] = "******"
+                    if "NewPassword" in debugjson.keys():
+                        debugjson["NewPassword"] = "******"
                     logbody = json.dumps(debugjson)
-                LOGGER.debug('HTTP REQUEST: %s\n\tPATH: %s\n\t'
-                             'HEADERS: %s\n\tBODY: %s', restreq.method, restreq.path, headers,
-                             logbody)
+                LOGGER.debug(
+                    "HTTP REQUEST: %s\n\tPATH: %s\n\t" "HEADERS: %s\n\tBODY: %s",
+                    restreq.method,
+                    restreq.path,
+                    headers,
+                    logbody,
+                )
             except:
-                LOGGER.debug('HTTP REQUEST: %s\n\tPATH: %s\n\tBODY: %s', restreq.method,
-                             restreq.path, 'binary body')
+                LOGGER.debug(
+                    "HTTP REQUEST: %s\n\tPATH: %s\n\tBODY: %s",
+                    restreq.method,
+                    restreq.path,
+                    "binary body",
+                )
 
         inittime = time.time()
         reqfullpath = self.base_url + reqpath if not external_uri else reqpath
@@ -248,11 +285,11 @@ class HttpConnection(object):
             reqfullpath = str(reqfullpath)
 
         if headers:
-            request_args['headers'] = headers
+            request_args["headers"] = headers
         if files:
-            request_args['fields'] = files
+            request_args["fields"] = files
         else:
-            request_args['body'] = body
+            request_args["body"] = body
         try:
             resp = self._conn(method, reqfullpath, **request_args)
         except MaxRetryError as excp:
@@ -264,37 +301,45 @@ class HttpConnection(object):
             raise DecompressResponseError()
 
         endtime = time.time()
-        LOGGER.info('Response Time to %s: %s seconds.', restreq.path, str(endtime - inittime))
+        LOGGER.info(
+            "Response Time to %s: %s seconds.", restreq.path, str(endtime - inittime)
+        )
 
         restresp = RestResponse(restreq, resp)
 
         if LOGGER.isEnabledFor(logging.DEBUG):
-            headerstr = ''
+            headerstr = ""
             if restresp is not None:
                 respheader = restresp.getheaders()
                 for kiy, headerval in respheader.items():
-                    headerstr += '\t' + kiy + ': ' + headerval + '\n'
+                    headerstr += "\t" + kiy + ": " + headerval + "\n"
                 try:
-                    LOGGER.debug('HTTP RESPONSE for %s:\nCode:%s\nHeaders:'
-                                 '\n%s\nBody Response of %s: %s', restresp.request.path,
-                                 str(restresp._http_response.status) + ' ' +
-                                 restresp._http_response.reason,
-                                 headerstr, restresp.request.path, restresp.read)
+                    LOGGER.debug(
+                        "HTTP RESPONSE for %s:\nCode:%s\nHeaders:"
+                        "\n%s\nBody Response of %s: %s",
+                        restresp.request.path,
+                        str(restresp._http_response.status)
+                        + " "
+                        + restresp._http_response.reason,
+                        headerstr,
+                        restresp.request.path,
+                        restresp.read,
+                    )
                 except:
-                    LOGGER.debug('HTTP RESPONSE:\nCode:%s', restresp)
+                    LOGGER.debug("HTTP RESPONSE:\nCode:%s", restresp)
             else:
-                LOGGER.debug('HTTP RESPONSE: No HTTP Response obtained')
+                LOGGER.debug("HTTP RESPONSE: No HTTP Response obtained")
 
         return restresp
 
     def cert_login(self):
         """Login using a certificate."""
-        resp = self.rest_request('/html/login_cert.html', 'GET')
+        resp = self.rest_request("/html/login_cert.html", "GET")
         if resp.status == 200 or resp.status == 201:
-            token = resp.getheader('X-Auth-Token')
-            location = resp.getheader('Location')
+            token = resp.getheader("X-Auth-Token")
+            location = resp.getheader("Location")
         else:
-            raise InvalidCertificateError('')
+            raise InvalidCertificateError("")
 
         return token, location
 
@@ -309,8 +354,9 @@ class Blobstore2Connection(object):
     :username: The username to login with
     :password: The password to login with
     """
-    _http_vsn_str = 'HTTP/1.1'
-    blobstore_headers = {'Accept': '*/*', 'Connection': 'Keep-Alive'}
+
+    _http_vsn_str = "HTTP/1.1"
+    blobstore_headers = {"Accept": "*/*", "Connection": "Keep-Alive"}
 
     def __del__(self):
         """Clear channel"""
@@ -320,38 +366,43 @@ class Blobstore2Connection(object):
         self._conn = None
         self.base_url = "blobstore://."
         self._connection_properties = conn_kwargs
-        self.session_key = self._connection_properties.pop('sessionid', None)
+        self.session_key = self._connection_properties.pop("sessionid", None)
         self._init_connection(**self._connection_properties)
 
     def _init_connection(self, **kwargs):
         """Initiate blobstore connection"""
         # mixed security modes require a password at all times
-        username = kwargs.pop('username', 'nousername')
+        username = kwargs.pop("username", "nousername")
         if isinstance(username, bytes):
-            username = username.decode('utf-8')
-        password = kwargs.pop('password', 'nopassword')
+            username = username.decode("utf-8")
+        password = kwargs.pop("password", "nopassword")
         if isinstance(password, bytes):
-            password = password.decode('utf-8')
+            password = password.decode("utf-8")
         try:
-            correctcreds = BlobStore2.initializecreds(username=username, password=password)
+            correctcreds = BlobStore2.initializecreds(
+                username=username, password=password
+            )
             bs2 = BlobStore2()
             if not correctcreds:
                 security_state = int(bs2.get_security_state())
-                raise SecurityStateError(security_state)
+                if security_state == 3:
+                    raise InvalidCredentialsError(0)
+                else:
+                    raise SecurityStateError(security_state)
         except Blob2SecurityError:
             raise InvalidCredentialsError(0)
         except HpIloChifPacketExchangeError as excp:
             LOGGER.info("Exception: %s", str(excp))
             raise ChifDriverMissingOrNotFound()
         except Exception as excp:
-            if str(excp) == 'chif':
+            if str(excp) == "chif":
                 raise ChifDriverMissingOrNotFound()
             else:
                 raise
         else:
             self._conn = bs2
 
-    def rest_request(self, path='', method="GET", args=None, body=None, headers=None):
+    def rest_request(self, path="", method="GET", args=None, body=None, headers=None):
         """Rest request for blobstore client
 
         :param path: The URI path to perform the operation on.
@@ -372,31 +423,32 @@ class Blobstore2Connection(object):
         else:
             headers.update(Blobstore2Connection.blobstore_headers)
         if isinstance(path, bytes):
-            path = path.decode('utf-8')
-        reqpath = path.replace('//', '/')
+            path = path.decode("utf-8")
+        reqpath = path.replace("//", "/")
 
         oribody = body
         if body is not None:
             if isinstance(body, (dict, list)):
-                headers['Content-Type'] = 'application/json'
+                headers["Content-Type"] = "application/json"
                 if isinstance(body, bytes):
-                    body = body.decode('utf-8')
+                    body = body.decode("utf-8")
                 body = json.dumps(body)
             else:
-                headers['Content-Type'] = 'application/x-www-form-urlencoded'
+                headers["Content-Type"] = "application/x-www-form-urlencoded"
                 body = urlencode(body)
 
-            if method == 'PUT':
+            if method == "PUT":
                 resp = self.rest_request(path=path, headers=headers)
 
                 try:
-                    if resp.getheader('content-encoding') == 'gzip':
+                    if resp.getheader("content-encoding") == "gzip":
                         buf = BytesIO()
-                        gfile = gzip.GzipFile(mode='wb', fileobj=buf)
+                        gfile = gzip.GzipFile(mode="wb", fileobj=buf)
 
                         try:
-                            gfile.write(str(body).encode('utf-8') if six.PY3 \
-                                            else str(body))
+                            gfile.write(
+                                str(body).encode("utf-8") if six.PY3 else str(body)
+                            )
                         finally:
                             gfile.close()
 
@@ -406,25 +458,25 @@ class Blobstore2Connection(object):
                             data.extend(memoryview(compresseddata))
                             body = data
                 except BaseException as excp:
-                    LOGGER.error('Error occur while compressing body: %s', excp)
+                    LOGGER.error("Error occur while compressing body: %s", excp)
                     raise
 
-            headers['Content-Length'] = len(body)
+            headers["Content-Length"] = len(body)
 
         if args:
-            if method == 'GET':
-                reqpath += '?' + urlencode(args)
-            elif method == 'PUT' or method == 'POST' or method == 'PATCH':
-                headers['Content-Type'] = 'application/x-www-form-urlencoded'
+            if method == "GET":
+                reqpath += "?" + urlencode(args)
+            elif method == "PUT" or method == "POST" or method == "PATCH":
+                headers["Content-Type"] = "application/x-www-form-urlencoded"
                 body = urlencode(args)
 
-        str1 = '{} {} {}\r\n'.format(method, reqpath, Blobstore2Connection._http_vsn_str)
-        str1 += 'Host: \r\n'
-        str1 += 'Accept-Encoding: gzip\r\n'
+        str1 = "{} {} {}\r\n".format(method, reqpath, Blobstore2Connection._http_vsn_str)
+        str1 += "Host: \r\n"
+        str1 += "Accept-Encoding: gzip\r\n"
         for header, value in headers.items():
-            str1 += '{}: {}\r\n'.format(header, value)
+            str1 += "{}: {}\r\n".format(header, value)
 
-        str1 += '\r\n'
+        str1 += "\r\n"
 
         if body and len(body) > 0:
             if isinstance(body, bytearray):
@@ -439,25 +491,35 @@ class Blobstore2Connection(object):
             try:
                 logbody = None
                 if body:
-                    if body[0] == '{':
+                    if body[0] == "{":
                         logbody = body
                     else:
                         raise
-                if method in ['POST', 'PATCH']:
+                if method in ["POST", "PATCH"]:
                     debugjson = json.loads(body)
-                    if 'Password' in debugjson.keys():
-                        debugjson['Password'] = '******'
-                    if 'OldPassword' in debugjson.keys():
-                        debugjson['OldPassword'] = '******'
-                    if 'NewPassword' in debugjson.keys():
-                        debugjson['NewPassword'] = '******'
+                    if "Password" in debugjson.keys():
+                        debugjson["Password"] = "******"
+                    if "OldPassword" in debugjson.keys():
+                        debugjson["OldPassword"] = "******"
+                    if "NewPassword" in debugjson.keys():
+                        debugjson["NewPassword"] = "******"
                     logbody = json.dumps(debugjson)
 
-                LOGGER.debug('Blobstore REQUEST: %s\n\tPATH: %s\n\tHEADERS: '
-                             '%s\n\tBODY: %s', method, str(headers), path, logbody)
+                LOGGER.debug(
+                    "Blobstore REQUEST: %s\n\tPATH: %s\n\tHEADERS: " "%s\n\tBODY: %s",
+                    method,
+                    str(headers),
+                    path,
+                    logbody,
+                )
             except:
-                LOGGER.debug('Blobstore REQUEST: %s\n\tPATH: %s\n\tHEADERS: '
-                             '%s\n\tBODY: %s', method, str(headers), path, 'binary body')
+                LOGGER.debug(
+                    "Blobstore REQUEST: %s\n\tPATH: %s\n\tHEADERS: " "%s\n\tBODY: %s",
+                    method,
+                    str(headers),
+                    path,
+                    "binary body",
+                )
 
         inittime = time.time()
 
@@ -478,11 +540,13 @@ class Blobstore2Connection(object):
         if resp_txt is not None:
             # Dummy response to support a bad host response
             if len(resp_txt) == 0:
-                resp_txt = "HTTP/1.1 500 Not Found\r\nAllow: " \
-                           "GET\r\nCache-Control: no-cache\r\nContent-length: " \
-                           "0\r\nContent-type: text/html\r\nDate: Tues, 1 Apr 2025 " \
-                           "00:00:01 GMT\r\nServer: " \
-                           "HP-iLO-Server/1.30\r\nX_HP-CHRP-Service-Version: 1.0.3\r\n\r\n\r\n"
+                resp_txt = (
+                    "HTTP/1.1 500 Not Found\r\nAllow: "
+                    "GET\r\nCache-Control: no-cache\r\nContent-length: "
+                    "0\r\nContent-type: text/html\r\nDate: Tues, 1 Apr 2025 "
+                    "00:00:01 GMT\r\nServer: "
+                    "HP-iLO-Server/1.30\r\nX_HP-CHRP-Service-Version: 1.0.3\r\n\r\n\r\n"
+                )
 
             restreq = RestRequest(path, method, data=body, url=self.base_url)
             rest_response = RisRestResponse(restreq, resp_txt)
@@ -491,10 +555,12 @@ class Blobstore2Connection(object):
                 newloc = rest_response.getheader("location")
                 newurl = urlparse(newloc)
 
-                rest_response = self.rest_request(newurl.path, method, args, oribody, headers)
+                rest_response = self.rest_request(
+                    newurl.path, method, args, oribody, headers
+                )
 
             try:
-                if rest_response.getheader('content-encoding') == 'gzip':
+                if rest_response.getheader("content-encoding") == "gzip":
                     if hasattr(gzip, "decompress"):
                         rest_response.read = gzip.decompress(rest_response.ori)
                     else:
@@ -504,29 +570,38 @@ class Blobstore2Connection(object):
             except Exception:
                 pass
             if LOGGER.isEnabledFor(logging.DEBUG):
-                headerstr = ''
+                headerstr = ""
                 headerget = rest_response.getheaders()
                 for header in headerget:
-                    headerstr += '\t' + header + ': ' + headerget[header] + '\n'
+                    headerstr += "\t" + header + ": " + headerget[header] + "\n"
                 try:
-                    LOGGER.debug('Blobstore RESPONSE for %s:\nCode: %s\nHeaders:'
-                                 '\n%s\nBody of %s: %s', rest_response.request.path,
-                                 str(rest_response._http_response.status) + ' ' +
-                                 rest_response._http_response.reason,
-                                headerstr, rest_response.request.path, rest_response.read)
+                    LOGGER.debug(
+                        "Blobstore RESPONSE for %s:\nCode: %s\nHeaders:"
+                        "\n%s\nBody of %s: %s",
+                        rest_response.request.path,
+                        str(rest_response._http_response.status)
+                        + " "
+                        + rest_response._http_response.reason,
+                        headerstr,
+                        rest_response.request.path,
+                        rest_response.read,
+                    )
                 except:
-                    LOGGER.debug('Blobstore RESPONSE for %s:\nCode:%s',
-                                 rest_response.request.path, rest_response)
+                    LOGGER.debug(
+                        "Blobstore RESPONSE for %s:\nCode:%s",
+                        rest_response.request.path,
+                        rest_response,
+                    )
             return rest_response
 
     def cert_login(self):
         """Login using a certificate."""
         # local cert login is only available on iLO 5
         token = self.cert_login()
-        resp = self.rest_request('/redfish/v1/SessionService/Sessions/', 'GET')
+        resp = self.rest_request("/redfish/v1/SessionService/Sessions/", "GET")
         if resp.status == 200:
             try:
-                location = resp.obj.Oem.Hpe.Links.MySession['@odata.id']
+                location = resp.obj.Oem.Hpe.Links.MySession["@odata.id"]
             except KeyError:
                 raise InvalidCertificateError("")
         else:
