@@ -23,8 +23,14 @@ import json
 import base64
 import hashlib
 import logging
+import sys
+from urllib.parse import urlparse
 
-from redfish.rest.connections import Blobstore2Connection, HttpConnection, InvalidCredentialsError
+from redfish.rest.connections import (
+    Blobstore2Connection,
+    HttpConnection,
+    InvalidCredentialsError,
+)
 
 # ---------End of imports---------
 
@@ -36,13 +42,16 @@ LOGGER = logging.getLogger(__name__)
 
 # ---------End of debug logger---------
 
+
 class ServerDownOrUnreachableError(Exception):
     """Raised when server is unreachable."""
+
     pass
 
 
 class JsonDecodingError(Exception):
     """Raised when there is an error in json data."""
+
     pass
 
 
@@ -51,9 +60,10 @@ class AuthMethod(object):
 
     **BASIC**, **SESSION**, **CERTIFICATE** variables translate to their string counterparts
     `basic`, `session`, `certificate`."""
-    BASIC = 'basic'
-    SESSION = 'session'
-    CERTIFICATE = 'certificate'
+
+    BASIC = "basic"
+    SESSION = "session"
+    CERTIFICATE = "certificate"
 
 
 class RestClientBase(object):
@@ -86,13 +96,19 @@ class RestClientBase(object):
 
     def _build_connection(self, **conn_kwargs):
         """Build the appropriate connection for the client"""
-        base_url = conn_kwargs.pop('base_url', None)
-        if not base_url or base_url.startswith('blobstore://'):
+        base_url = conn_kwargs.pop("base_url", None)
+        if not base_url or base_url.startswith("blobstore://"):
             self.connection = Blobstore2Connection(**conn_kwargs)
+        elif not base_url.startswith("https://"):
+            base_url = "https://" + base_url
+            _ = conn_kwargs.pop("username", None)
+            _ = conn_kwargs.pop("password", None)
+            _ = conn_kwargs.pop("sessionid", None)
+            self.connection = HttpConnection(base_url, self._cert_data, **conn_kwargs)
         else:
-            _ = conn_kwargs.pop('username', None)
-            _ = conn_kwargs.pop('password', None)
-            _ = conn_kwargs.pop('sessionid', None)
+            _ = conn_kwargs.pop("username", None)
+            _ = conn_kwargs.pop("password", None)
+            _ = conn_kwargs.pop("sessionid", None)
             self.connection = HttpConnection(base_url, self._cert_data, **conn_kwargs)
 
     def _get_req_headers(self, headers=None):
@@ -111,11 +127,15 @@ class RestClientBase(object):
         :returns: A :class:`redfish.rest.containers.RestResponse` object
         """
         try:
-            return self.connection.rest_request(path, method='GET', args=args,
-                                                headers=self._get_req_headers(headers=headers))
+            return self.connection.rest_request(
+                path,
+                method="GET",
+                args=args,
+                headers=self._get_req_headers(headers=headers),
+            )
         except ValueError:
             LOGGER.debug("Error in json object getting path: %s", path)
-            raise JsonDecodingError('Error in json decoding.')
+            raise JsonDecodingError("Error in json decoding.")
 
     def patch(self, path, body, args=None, headers=None):
         """Perform a PATCH request
@@ -130,8 +150,13 @@ class RestClientBase(object):
         :type headers: dict
         :returns: A :class:`redfish.rest.containers.RestResponse` object
         """
-        return self.connection.rest_request(path, body=body,
-                                            method='PATCH', args=args, headers=self._get_req_headers(headers=headers))
+        return self.connection.rest_request(
+            path,
+            body=body,
+            method="PATCH",
+            args=args,
+            headers=self._get_req_headers(headers=headers),
+        )
 
     def post(self, path, body, args=None, headers=None):
         """Perform a POST request
@@ -146,8 +171,13 @@ class RestClientBase(object):
         :type headers: dict
         :returns: A :class:`redfish.rest.containers.RestResponse` object
         """
-        return self.connection.rest_request(path, body=body,
-                                            method='POST', args=args, headers=self._get_req_headers(headers=headers))
+        return self.connection.rest_request(
+            path,
+            body=body,
+            method="POST",
+            args=args,
+            headers=self._get_req_headers(headers=headers),
+        )
 
     def put(self, path, body, args=None, headers=None):
         """Perform a PUT request
@@ -162,8 +192,13 @@ class RestClientBase(object):
         :type headers: dict
         :returns: A :class:`redfish.rest.containers.RestResponse` object
         """
-        return self.connection.rest_request(path, body=body,
-                                            method='PUT', args=args, headers=self._get_req_headers(headers=headers))
+        return self.connection.rest_request(
+            path,
+            body=body,
+            method="PUT",
+            args=args,
+            headers=self._get_req_headers(headers=headers),
+        )
 
     def head(self, path, headers=None):
         """Perform a HEAD request
@@ -174,8 +209,9 @@ class RestClientBase(object):
         :type headers: dict
         :returns: A :class:`redfish.rest.containers.RestResponse` object
         """
-        return self.connection.rest_request(path, method='HEAD',
-                                            headers=self._get_req_headers(headers=headers))
+        return self.connection.rest_request(
+            path, method="HEAD", headers=self._get_req_headers(headers=headers)
+        )
 
     def delete(self, path, headers=None):
         """Perform a DELETE request
@@ -186,8 +222,9 @@ class RestClientBase(object):
         :type args: dict
         :returns: A :class:`redfish.rest.containers.RestResponse` object
         """
-        return self.connection.rest_request(path, method='DELETE',
-                                            headers=self._get_req_headers(headers=headers))
+        return self.connection.rest_request(
+            path, method="DELETE", headers=self._get_req_headers(headers=headers)
+        )
 
 
 class RestClient(RestClientBase):
@@ -209,19 +246,36 @@ class RestClient(RestClientBase):
     :param \\**client_kwargs: Arguments to create a :class:`RestClientBase` instance.
     """
 
-    def __init__(self, default_prefix='/redfish/v1/', is_redfish=True, username=None, password=None, sessionid=None,
-                 base_url=None, auth=None, ca_cert_data=None, **client_kwargs):
+    def __init__(
+        self,
+        default_prefix="/redfish/v1/",
+        is_redfish=True,
+        username=None,
+        password=None,
+        sessionid=None,
+        base_url=None,
+        auth=None,
+        ca_cert_data=None,
+        **client_kwargs
+    ):
         """Create a Rest Client object"""
         self.default_prefix = default_prefix
         self.is_redfish = is_redfish
         self.root = None
-        self.auth_type = self._get_auth_type(auth, ca_cert_data=ca_cert_data, **client_kwargs)
+        self.auth_type = self._get_auth_type(
+            auth, ca_cert_data=ca_cert_data, **client_kwargs
+        )
         self._auth_key = None
         self._user_pass = (username, password)
         self._session_location = None
         self._cert_data = ca_cert_data
-        super(RestClient, self).__init__(username=username, password=password, sessionid=sessionid, base_url=base_url,
-                                         **client_kwargs)
+        super(RestClient, self).__init__(
+            username=username,
+            password=password,
+            sessionid=sessionid,
+            base_url=base_url,
+            **client_kwargs
+        )
 
     def __enter__(self):
         """Create a connection and return the session object"""
@@ -234,12 +288,16 @@ class RestClient(RestClientBase):
 
     def _get_auth_type(self, auth_param, ca_cert_data=None, **client_kwargs):
         """Get the auth type based on key args or positional argument.
-            Defaults to session auth."""
+        Defaults to session auth."""
         if not auth_param:
             # _ca_cert_data = client_kwargs.get('ca_cert_data')
             if ca_cert_data:
-                if ('ca_certs' in ca_cert_data and ca_cert_data['ca_certs']) or ('cert_file' in ca_cert_data and ca_cert_data['cert_file']):
-                    if (ca_cert_data.get('cert_file') and ca_cert_data.get('key_file')) or ca_cert_data.get('ca_certs'):
+                if ("ca_certs" in ca_cert_data and ca_cert_data["ca_certs"]) or (
+                    "cert_file" in ca_cert_data and ca_cert_data["cert_file"]
+                ):
+                    if (
+                        ca_cert_data.get("cert_file") and ca_cert_data.get("key_file")
+                    ) or ca_cert_data.get("ca_certs"):
                         return AuthMethod.CERTIFICATE
             return AuthMethod.SESSION
 
@@ -262,8 +320,11 @@ class RestClient(RestClientBase):
     @property
     def session_key(self):
         """The Client's session key, if any."""
-        return self._auth_key if self.auth_type in \
-                                 [AuthMethod.SESSION, AuthMethod.CERTIFICATE] else None
+        return (
+            self._auth_key
+            if self.auth_type in [AuthMethod.SESSION, AuthMethod.CERTIFICATE]
+            else None
+        )
 
     @session_key.setter
     def session_key(self, ses_key):
@@ -286,16 +347,33 @@ class RestClient(RestClientBase):
         session_loc = None
         if self._session_location:
             if self.base_url == "blobstore://.":
-                session_loc = self._session_location.replace("https://", '')
-                session_loc = session_loc.replace(' ', '%20')
+                session_loc = self._session_location.replace("https://", "")
+                session_loc = session_loc.replace(" ", "%20")
             else:
-                session_loc = self._session_location.replace(self.base_url, '')
+                parse_object = urlparse(self.base_url)
+                if parse_object.hostname != None:
+                    newurl = "https://" + parse_object.hostname
+                    session_loc = self._session_location.replace(newurl, "")
+                else:
+                    session_loc = self._session_location.replace(self.base_url, "")
         return session_loc
 
     @session_location.setter
     def session_location(self, ses_loc):
         """Set the session URI"""
-        self._session_location = ses_loc
+        login_url_p = urlparse(self.base_url)
+        new_port = login_url_p.port
+        # The session_url returned by iLO does not include the port information
+        # If we're using a non-standard port to connect to iLO we have to
+        # manually insert it, based on the base_url.
+        if new_port and ses_loc:
+            session_location_p = urlparse(ses_loc)
+            session_location_p = session_location_p._replace(
+                netloc="{}:{}".format(session_location_p.hostname, new_port)
+            )
+            self._session_location = session_location_p.geturl()
+        else:
+            self._session_location = ses_loc
 
     @property
     def username(self):
@@ -316,13 +394,14 @@ class RestClient(RestClientBase):
         login_url = None
 
         try:
-            login_url = self.root.obj.Links.Sessions['@odata.id']
+            login_url = self.root.obj.Links.Sessions["@odata.id"]
         except KeyError:
             login_url = self.root.obj.links.Sessions.href
         finally:
             if not login_url:
-                raise ServerDownOrUnreachableError("Cannot locate the login url. Is this a Rest or"
-                                                   " Redfish server?")
+                raise ServerDownOrUnreachableError(
+                    "Cannot locate the login url. Is this a Rest or" " Redfish server?"
+                )
         return login_url
 
     def login(self, auth=AuthMethod.SESSION):
@@ -349,7 +428,7 @@ class RestClient(RestClientBase):
             self._get_root()
 
     def logout(self):
-        """ Logout of session.
+        """Logout of session.
 
         YOU MUST CALL THIS WHEN YOU ARE DONE TO FREE UP SESSIONS"""
         if self.session_location:
@@ -359,25 +438,27 @@ class RestClient(RestClientBase):
         self.session_location = None
 
     def _get_root(self):
-        """ Get the root response of the server """
+        """Get the root response of the server"""
         if not self.root:
             resp = self.get(self.default_prefix)
 
             if resp.status != 200:
-                raise ServerDownOrUnreachableError("Server not reachable, " \
-                                                   "return code: %d" % resp.status)
+                raise ServerDownOrUnreachableError(
+                    "Server not reachable, " "return code: %d" % resp.status
+                )
             self.root = resp
 
     def _basic_login(self):
-        """ Login using basic authentication """
-        LOGGER.info('Performing basic authentication.')
+        """Login using basic authentication"""
+        LOGGER.info("Performing basic authentication.")
         if not self.basic_auth:
-            auth_key = base64.b64encode(('{}:{}'.format(self.username,
-                                                        self.password)).encode('utf-8')).decode('utf-8')
-            self.basic_auth = 'Basic {}'.format(auth_key)
+            auth_key = base64.b64encode(
+                ("{}:{}".format(self.username, self.password)).encode("utf-8")
+            ).decode("utf-8")
+            self.basic_auth = "Basic {}".format(auth_key)
 
         headers = dict()
-        headers['Authorization'] = self.basic_auth
+        headers["Authorization"] = self.basic_auth
 
         respvalidate = self.get(self.login_url, headers=headers)
 
@@ -389,18 +470,18 @@ class RestClient(RestClientBase):
     def _session_login(self):
         """Login using session authentication"""
         if not self.connection.session_key:
-            LOGGER.info('Performing session authentication.')
+            LOGGER.info("Performing session authentication.")
             data = dict()
-            data['UserName'] = self.username
-            data['Password'] = self.password
+            data["UserName"] = self.username
+            data["Password"] = self.password
 
             headers = dict()
             resp = self.post(self.login_url, body=data, headers=headers)
             try:
-                LOGGER.info(json.loads('%s' % resp.read))
+                LOGGER.info(json.loads("%s" % resp.read))
             except ValueError:
                 pass
-            LOGGER.info('Login returned code %s: %s', resp.status, resp.read)
+            LOGGER.info("Login returned code %s: %s", resp.status, resp.read)
 
             self.session_key = resp.session_key
             self.session_location = resp.session_location
@@ -439,26 +520,81 @@ class RestClient(RestClientBase):
         """
         headers = headers if isinstance(headers, dict) else dict()
         h_list = [header.lower() for header in headers]
-        auth_headers = True if 'x-auth-token' in h_list or 'authorization' in h_list else False
+        auth_headers = (
+            True if "x-auth-token" in h_list or "authorization" in h_list else False
+        )
 
         token = self._biospassword if self._biospassword else optionalpassword
         if token:
-            token = optionalpassword.encode('utf-8') if type(
-                optionalpassword).__name__ in 'basestr' else token
-            hash_object = hashlib.new('SHA256')
+            token = (
+                optionalpassword.encode("utf-8")
+                if type(optionalpassword).__name__ in "basestr"
+                else token
+            )
+            hash_object = hashlib.new("SHA256")
             hash_object.update(token)
-            headers['X-HPRESTFULAPI-AuthToken'] = hash_object.hexdigest().upper()
+            headers["X-HPRESTFULAPI-AuthToken"] = hash_object.hexdigest().upper()
 
         if self.session_key and not auth_headers:
-            headers['X-Auth-Token'] = self.session_key
+            headers["X-Auth-Token"] = self.session_key
         elif self.basic_auth and not auth_headers:
-            headers['Authorization'] = self.basic_auth
+            headers["Authorization"] = self.basic_auth
 
         if self.is_redfish:
-            headers['OData-Version'] = '4.0'
+            headers["OData-Version"] = "4.0"
 
         return headers
 
+    def get_resource_directory(self):
+        try:
+            resource_uri = self.root.obj.Oem.Hpe.Links.ResourceDirectory["@odata.id"]
+        except KeyError:
+            sys.stderr.write("Resource directory is only available on HPE servers.\n")
+            return None
+
+        response = self.get(resource_uri)
+        resources = []
+
+        if response.status == 200:
+            sys.stdout.write(
+                "\tFound resource directory at /redfish/v1/resourcedirectory" + "\n\n"
+            )
+            resources = response.dict["Instances"]
+        else:
+            sys.stderr.write(
+                "\tResource directory missing at /redfish/v1/resourcedirectory" + "\n"
+            )
+
+        return resources
+
+    def get_gen(self):
+        rootresp = self.root.obj
+        # Default iLO 5
+        ilogen = 5
+        iloversion = None
+        gencompany = next(iter(rootresp.get("Oem", {}).keys()), None) in ("Hpe", "Hp")
+        comp = "Hp" if gencompany else None
+        comp = "Hpe" if rootresp.get("Oem", {}).get("Hpe", None) else comp
+        if comp and next(
+            iter(rootresp.get("Oem", {}).get(comp, {}).get("Manager", {}))
+        ).get("ManagerType", None):
+            ilogen = next(
+                iter(rootresp.get("Oem", {}).get(comp, {}).get("Manager", {}))
+            ).get("ManagerType")
+            ilover = next(
+                iter(rootresp.get("Oem", {}).get(comp, {}).get("Manager", {}))
+            ).get("ManagerFirmwareVersion")
+            if ilogen.split(" ")[-1] == "CM":
+                # Assume iLO 4 types in Moonshot
+                ilogen = 4
+                iloversion = None
+            else:
+                ilogen = ilogen.split(" ")[1]
+                iloversion = float(
+                    ilogen.split(" ")[-1] + "." + "".join(ilover.split("."))
+                )
+        return (ilogen, iloversion)
+
 
 class LegacyRestClient(RestClient):
     """Class for a **Legacy REST** client instance.
@@ -474,8 +610,9 @@ class LegacyRestClient(RestClient):
     For full description of the arguments allowed see :class:`RestClient`"""
 
     def __init__(self, **client_kwargs):
-        super(LegacyRestClient, self).__init__(default_prefix='/rest/v1', is_redfish=False,
-                                               **client_kwargs)
+        super(LegacyRestClient, self).__init__(
+            default_prefix="/rest/v1", is_redfish=False, **client_kwargs
+        )
 
 
 class RedfishClient(RestClient):
@@ -492,5 +629,6 @@ class RedfishClient(RestClient):
     For full description of the arguments allowed see :class:`RestClient`"""
 
     def __init__(self, **client_kwargs):
-        super(RedfishClient, self).__init__(default_prefix='/redfish/v1/', is_redfish=True,
-                                            **client_kwargs)
+        super(RedfishClient, self).__init__(
+            default_prefix="/redfish/v1/", is_redfish=True, **client_kwargs
+        )
